@@ -3,7 +3,7 @@
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 from warnings import warn
@@ -641,7 +641,10 @@ def global_pairwise_align(seq1, seq2, gap_open_penalty, gap_extend_penalty,
     return msa, score, start_end_positions
 
 
-@experimental(as_of="0.4.0")
+@deprecated(as_of="0.5.8", until="0.6.0",
+            reason="This will be removed or replaced, in favor of more general"
+                   "-purpose performant aligners. Additional details at "
+                   "https://github.com/biocore/scikit-bio/issues/1814")
 def local_pairwise_align_ssw(sequence1, sequence2, **kwargs):
     """Align query and target sequences with Striped Smith-Waterman.
 
@@ -793,7 +796,7 @@ _traceback_encoding = {'match': 1, 'vertical-gap': 2, 'horizontal-gap': 3,
 def _init_matrices_sw(aln1, aln2, gap_open_penalty, gap_extend_penalty):
     shape = (aln2.shape.position+1, aln1.shape.position+1)
     score_matrix = np.zeros(shape)
-    traceback_matrix = np.zeros(shape, dtype=np.int)
+    traceback_matrix = np.zeros(shape, dtype=int)
     traceback_matrix += _traceback_encoding['uninitialized']
     traceback_matrix[0, :] = _traceback_encoding['alignment-end']
     traceback_matrix[:, 0] = _traceback_encoding['alignment-end']
@@ -803,7 +806,7 @@ def _init_matrices_sw(aln1, aln2, gap_open_penalty, gap_extend_penalty):
 def _init_matrices_nw(aln1, aln2, gap_open_penalty, gap_extend_penalty):
     shape = (aln2.shape.position+1, aln1.shape.position+1)
     score_matrix = np.zeros(shape)
-    traceback_matrix = np.zeros(shape, dtype=np.int)
+    traceback_matrix = np.zeros(shape, dtype=int)
     traceback_matrix += _traceback_encoding['uninitialized']
     traceback_matrix[0, 0] = _traceback_encoding['alignment-end']
 
@@ -826,7 +829,7 @@ def _init_matrices_nw_no_terminal_gap_penalty(
         aln1, aln2, gap_open_penalty, gap_extend_penalty):
     shape = (aln2.shape.position+1, aln1.shape.position+1)
     score_matrix = np.zeros(shape)
-    traceback_matrix = np.zeros(shape, dtype=np.int)
+    traceback_matrix = np.zeros(shape, dtype=int)
     traceback_matrix += _traceback_encoding['uninitialized']
     traceback_matrix[0, 0] = _traceback_encoding['alignment-end']
 
