@@ -3,7 +3,7 @@
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 from unittest import TestCase, main
@@ -215,9 +215,9 @@ class BaseTests(TestCase):
 
         self.assertAlmostEqual(pielou_e(self.counts), 0.92485490560)
 
-        self.assertEqual(pielou_e([1, 1]), 1.0)
-        self.assertEqual(pielou_e([1, 1, 1, 1]), 1.0)
-        self.assertEqual(pielou_e([1, 1, 1, 1, 0, 0]), 1.0)
+        self.assertAlmostEqual(pielou_e([1, 1]), 1.0)
+        self.assertAlmostEqual(pielou_e([1, 1, 1, 1]), 1.0)
+        self.assertAlmostEqual(pielou_e([1, 1, 1, 1, 0, 0]), 1.0)
 
         # Examples from
         # http://ww2.mdsg.umd.edu/interactive_lessons/biofilm/diverse.htm#3
