@@ -3,7 +3,7 @@
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 import functools
@@ -89,6 +89,9 @@ def unweighted_unifrac(u_counts, v_counts, otu_ids, tree, validate=True):
     This implementation of unweighted UniFrac is the array-based implementation
     described in [4]_.
 
+    If using large number of samples or a large tree, we advise using the
+    optimized UniFrac library [5]_.
+
     References
     ----------
     .. [1] Lozupone, C. & Knight, R. UniFrac: a new phylogenetic method for
@@ -109,6 +112,8 @@ def unweighted_unifrac(u_counts, v_counts, otu_ids, tree, validate=True):
        analysis of pyrosequencing and PhyloChip data.  ISME J. 4(1):17-27
        (2010).
 
+    .. [5] https://github.com/biocore/unifrac
+
     Examples
     --------
     Assume we have the following abundance data for two samples, ``u`` and
@@ -219,6 +224,9 @@ def weighted_unifrac(u_counts, v_counts, otu_ids, tree,
     This implementation of weighted UniFrac is the array-based implementation
     described in [3]_.
 
+    If using large number of samples or a large tree, we advise using the
+    optimized UniFrac library [4]_.
+
     References
     ----------
     .. [1] Lozupone, C. A., Hamady, M., Kelley, S. T. & Knight, R. Quantitative
@@ -235,6 +243,8 @@ def weighted_unifrac(u_counts, v_counts, otu_ids, tree,
        analysis of pyrosequencing and PhyloChip data.  ISME J. 4(1):17-27
        (2010).
 
+    .. [4] https://github.com/biocore/unifrac
+
     Examples
     --------
     Assume we have the following abundance data for two samples, ``u`` and
