@@ -15,6 +15,7 @@ see the associated documentation.
 .. autosummary::
    :toctree: generated/
 
+   binary_dm
    blast6
    blast7
    clustal
@@ -29,6 +30,7 @@ see the associated documentation.
    phylip
    qseq
    stockholm
+   taxdump
 
 .. currentmodule:: skbio.io.registry
 
@@ -195,7 +197,7 @@ not know how you want to serialize an object. OO interfaces define a default
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 from importlib import import_module
@@ -251,6 +253,8 @@ import_module('skbio.io.format.qseq')
 import_module('skbio.io.format.genbank')
 import_module('skbio.io.format.gff3')
 import_module('skbio.io.format.stockholm')
+import_module('skbio.io.format.binary_dm')
+import_module('skbio.io.format.taxdump')
 
 # This is meant to be a handy indicator to the user that they have done
 # something wrong.
