@@ -210,11 +210,11 @@ Specifications/blob/master/gff3.md
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 import re
-from collections import Iterable
+from collections.abc import Iterable
 
 from skbio.sequence import DNA, Sequence
 from skbio.io import create_format, GFF3FormatError
