@@ -67,7 +67,7 @@ or writing to a file.
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 import csv
@@ -225,7 +225,7 @@ def _matrix_to_lsmat(obj, fh, delimiter):
     for id_, vals in zip(ids, obj.data):
         fh.write("%s" % id_)
         fh.write(delimiter)
-        fh.write(delimiter.join(np.asarray(vals, dtype=np.str)))
+        fh.write(delimiter.join(np.asarray(vals, dtype=str)))
         fh.write('\n')
 
 
