@@ -3,7 +3,7 @@
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 import copy
@@ -715,9 +715,12 @@ class PositionalMetadataMixinTests:
         # array-like objects will fail if wrong size.
         for array_like in (np.array(range(length-1)), range(length-1),
                            np.array(range(length+1)), range(length+1)):
+
             with self.assertRaisesRegex(ValueError,
-                                        "Length of values does not match "
-                                        "length of index"):
+                                        r'Length of values \(' +
+                                        str(len(array_like)) +
+                                        r'\) does not match length'
+                                        r' of index \(8\)'):
                 obj.positional_metadata['bar'] = array_like
 
     def test_positional_metadata_setter_pandas_consumable(self):
