@@ -3,7 +3,7 @@
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 from abc import ABCMeta, abstractproperty
@@ -345,7 +345,7 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
                 "Note: Use `lowercase` if your sequence contains lowercase "
                 "characters not in the sequence's alphabet."
                 % ('s' if len(bad) > 1 else '',
-                   [str(b.tostring().decode("ascii")) for b in bad] if
+                   [str(b.tobytes().decode("ascii")) for b in bad] if
                    len(bad) > 1 else bad[0],
                    list(self.alphabet)))
 
