@@ -99,7 +99,7 @@ array([ 0.25,  0.25,  0.5 ])
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 import numpy as np
@@ -903,14 +903,18 @@ def ancom(table, grouping,
     The developers of this method recommend the following significance tests
     ([2]_, Supplementary File 1, top of page 11): if there are 2 groups, use
     the standard parametric t-test (``scipy.stats.ttest_ind``) or
-    non-parametric Wilcoxon rank sum test (``scipy.stats.wilcoxon``).
-    If there are more than 2 groups, use parametric one-way ANOVA
-    (``scipy.stats.f_oneway``) or nonparametric Kruskal-Wallis
-    (``scipy.stats.kruskal``). Because one-way ANOVA is equivalent
-    to the standard t-test when the number of groups is two, we default to
-    ``scipy.stats.f_oneway`` here, which can be used when there are two or
-    more groups.  Users should refer to the documentation of these tests in
-    SciPy to understand the assumptions made by each test.
+    non-parametric Mann-Whitney rank test (``scipy.stats.mannwhitneyu``).
+    For paired samples, use the parametric paired t-test
+    (``scipy.stats.ttest_rel``) or nonparametric Wilcoxon signed-rank test
+    (``scipy.stats.wilcoxon``). If there are more than 2 groups, use
+    parametric one-way ANOVA (``scipy.stats.f_oneway``) or nonparametric
+    Kruskal-Wallis (``scipy.stats.kruskal``). If there are multiple
+    measurements obtained from the individuals, use a Friedman test
+    (``scipy.stats.friedmanchisquare``).  Because one-way ANOVA is
+    equivalent to the standard t-test when the number of groups is two, we
+    default to ``scipy.stats.f_oneway`` here, which can be used when there
+    are two or more groups. Users should refer to the documentation of these
+    tests in SciPy to understand the assumptions made by each test.
 
     This method cannot handle any zero counts as input, since the logarithm
     of zero cannot be computed.  While this is an unsolved problem, many
@@ -1185,7 +1189,7 @@ def _holm_bonferroni(p):
 def _log_compare(mat, cats,
                  significance_test=scipy.stats.ttest_ind):
     """ Calculates pairwise log ratios between all features and performs a
-    significiance test (i.e. t-test) to determine if there is a significant
+    significance test (i.e. t-test) to determine if there is a significant
     difference in feature ratios with respect to the variable of interest.
 
     Parameters
