@@ -90,7 +90,7 @@ Control
 #
 # Distributed under the terms of the Modified BSD License.
 #
-# The full license is in the file COPYING.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
 from copy import deepcopy
@@ -168,7 +168,7 @@ def _weight_by_vector(trajectories, w_vector):
                 np.abs((w_vector[i] - w_vector[i-1]))
             )
 
-    return trajectories
+    return trajectories.astype('float64')
 
 
 def _ANOVA_trajectories(category, res_by_group):
